The macros use by tauri_interop to generate dynamic code depending on the target

Macros

  • Collects all commands annotated with command and provides these with a get_handlers() in the current namespace

Attribute Macros

  • Generates the wasm counterpart to a defined tauri::command
  • Conditionally adds binding or tauri::command to a struct
  • Generates an emit function for the given struct with a correlation enum for emitting a single field of the struct.
  • Conditionally adds listen_to or emit to a struct
  • Simple macro to include given use only in host
  • Generates listen_to_<field> functions for the given struct for the correlating host code.
  • Simple macro to include given use only in wasm